# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteBureaus(BaseModel):
    delete_bureaus: Optional[list[Optional["DeleteBureausDeleteBureaus"]]] = Field(
        alias="deleteBureaus"
    )


class DeleteBureausDeleteBureaus(BaseModel):
    id: str
    state: EntityState


DeleteBureaus.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, LinkTypes


class QueryInvestmentFundsExpanded(BaseModel):
    investment_funds: Optional["QueryInvestmentFundsExpandedInvestmentFunds"] = Field(
        alias="investmentFunds"
    )


class QueryInvestmentFundsExpandedInvestmentFunds(BaseModel):
    results: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResults"]]
    ]


class QueryInvestmentFundsExpandedInvestmentFundsResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryInvestmentFundsExpandedInvestmentFundsResultsOwner"
    state: EntityState
    alternate_names: Optional[list[Optional[str]]] = Field(alias="alternateNames")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    feeds: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsFeeds"]]
    ]
    links: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsLinks"]]
    ]
    workflow: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsWorkflow"]
    location: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsLocation"]
    h_3: Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsH3"] = Field(
        alias="h3"
    )
    amount: Optional[Any]
    amount_currency: Optional[str] = Field(alias="amountCurrency")
    fund_type: Optional[str] = Field(alias="fundType")
    vintage: Optional[int]
    target_size: Optional[Any] = Field(alias="targetSize")
    target_size_currency: Optional[str] = Field(alias="targetSizeCurrency")
    organizations: Optional[
        list[
            Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsOrganizations"]
        ]
    ]
    investments: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsInvestments"]]
    ]
    parent_fund: Optional[
        "QueryInvestmentFundsExpandedInvestmentFundsResultsParentFund"
    ] = Field(alias="parentFund")
    child_funds: Optional[
        list[Optional["QueryInvestmentFundsExpandedInvestmentFundsResultsChildFunds"]]
    ] = Field(alias="childFunds")


class QueryInvestmentFundsExpandedInvestmentFundsResultsOwner(BaseModel):
    id: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsFeeds(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsLinks(BaseModel):
    uri: Optional[Any]
    link_type: Optional[LinkTypes] = Field(alias="linkType")
    excerpts: Optional[str]


class QueryInvestmentFundsExpandedInvestmentFundsResultsWorkflow(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsLocation(BaseModel):
    latitude: Optional[float]
    longitude: Optional[float]


class QueryInvestmentFundsExpandedInvestmentFundsResultsH3(BaseModel):
    h_3_r_0: Optional[str] = Field(alias="h3r0")
    h_3_r_1: Optional[str] = Field(alias="h3r1")
    h_3_r_2: Optional[str] = Field(alias="h3r2")
    h_3_r_3: Optional[str] = Field(alias="h3r3")
    h_3_r_4: Optional[str] = Field(alias="h3r4")
    h_3_r_5: Optional[str] = Field(alias="h3r5")
    h_3_r_6: Optional[str] = Field(alias="h3r6")
    h_3_r_7: Optional[str] = Field(alias="h3r7")
    h_3_r_8: Optional[str] = Field(alias="h3r8")
    h_3_r_9: Optional[str] = Field(alias="h3r9")
    h_3_r_10: Optional[str] = Field(alias="h3r10")
    h_3_r_11: Optional[str] = Field(alias="h3r11")
    h_3_r_12: Optional[str] = Field(alias="h3r12")
    h_3_r_13: Optional[str] = Field(alias="h3r13")
    h_3_r_14: Optional[str] = Field(alias="h3r14")
    h_3_r_15: Optional[str] = Field(alias="h3r15")


class QueryInvestmentFundsExpandedInvestmentFundsResultsOrganizations(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsInvestments(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsParentFund(BaseModel):
    id: str
    name: str


class QueryInvestmentFundsExpandedInvestmentFundsResultsChildFunds(BaseModel):
    id: str
    name: str


QueryInvestmentFundsExpanded.model_rebuild()
QueryInvestmentFundsExpandedInvestmentFunds.model_rebuild()
QueryInvestmentFundsExpandedInvestmentFundsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateBureau(BaseModel):
    update_bureau: Optional["UpdateBureauUpdateBureau"] = Field(alias="updateBureau")


class UpdateBureauUpdateBureau(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]


UpdateBureau.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class RemoveAgentsFromDesk(BaseModel):
    remove_agents_from_desk: Optional["RemoveAgentsFromDeskRemoveAgentsFromDesk"] = (
        Field(alias="removeAgentsFromDesk")
    )


class RemoveAgentsFromDeskRemoveAgentsFromDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["RemoveAgentsFromDeskRemoveAgentsFromDeskBureau"]
    agents: Optional[list[Optional["RemoveAgentsFromDeskRemoveAgentsFromDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class RemoveAgentsFromDeskRemoveAgentsFromDeskBureau(BaseModel):
    id: str


class RemoveAgentsFromDeskRemoveAgentsFromDeskAgents(BaseModel):
    id: str
    name: str


RemoveAgentsFromDesk.model_rebuild()
RemoveAgentsFromDeskRemoveAgentsFromDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountBureaus(BaseModel):
    count_bureaus: Optional["CountBureausCountBureaus"] = Field(alias="countBureaus")


class CountBureausCountBureaus(BaseModel):
    count: Optional[Any]


CountBureaus.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class QueryBureaus(BaseModel):
    bureaus: Optional["QueryBureausBureaus"]


class QueryBureausBureaus(BaseModel):
    results: Optional[list["QueryBureausBureausResults"]]


class QueryBureausBureausResults(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    relevance: Optional[float]
    owner: "QueryBureausBureausResultsOwner"
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desk_count: Optional[int] = Field(alias="deskCount")


class QueryBureausBureausResultsOwner(BaseModel):
    id: str


QueryBureaus.model_rebuild()
QueryBureausBureaus.model_rebuild()
QueryBureausBureausResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountDesks(BaseModel):
    count_desks: Optional["CountDesksCountDesks"] = Field(alias="countDesks")


class CountDesksCountDesks(BaseModel):
    count: Optional[Any]


CountDesks.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteBureau(BaseModel):
    delete_bureau: Optional["DeleteBureauDeleteBureau"] = Field(alias="deleteBureau")


class DeleteBureauDeleteBureau(BaseModel):
    id: str
    state: EntityState


DeleteBureau.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetBureau(BaseModel):
    bureau: Optional["GetBureauBureau"]


class GetBureauBureau(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetBureauBureauOwner"
    state: EntityState
    description: Optional[str]
    mission: Optional[str]
    directives: Optional[str]
    desks: Optional[list[Optional["GetBureauBureauDesks"]]]
    desk_count: Optional[int] = Field(alias="deskCount")


class GetBureauBureauOwner(BaseModel):
    id: str


class GetBureauBureauDesks(BaseModel):
    id: str
    name: str


GetBureau.model_rebuild()
GetBureauBureau.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllDesks(BaseModel):
    delete_all_desks: Optional[list[Optional["DeleteAllDesksDeleteAllDesks"]]] = Field(
        alias="deleteAllDesks"
    )


class DeleteAllDesksDeleteAllDesks(BaseModel):
    id: str
    state: EntityState


DeleteAllDesks.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityOwners, EntityState


class GetSkill(BaseModel):
    skill: Optional["GetSkillSkill"]


class GetSkillSkill(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetSkillSkillOwner"
    state: EntityState
    user: Optional["GetSkillSkillUser"]
    description: Optional[str]
    identifier: Optional[str]
    correlation_id: Optional[str] = Field(alias="correlationId")
    text: str
    skill_owner: Optional[EntityOwners] = Field(alias="skillOwner")
    arguments: Optional[list["GetSkillSkillArguments"]]
    collections: Optional[list[Optional["GetSkillSkillCollections"]]]


class GetSkillSkillOwner(BaseModel):
    id: str


class GetSkillSkillUser(BaseModel):
    id: str


class GetSkillSkillArguments(BaseModel):
    name: str
    description: Optional[str]
    required: Optional[bool]


class GetSkillSkillCollections(BaseModel):
    id: str
    name: str


GetSkill.model_rebuild()
GetSkillSkill.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class CreateDesk(BaseModel):
    create_desk: Optional["CreateDeskCreateDesk"] = Field(alias="createDesk")


class CreateDeskCreateDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["CreateDeskCreateDeskBureau"]


class CreateDeskCreateDeskBureau(BaseModel):
    id: str


CreateDesk.model_rebuild()
CreateDeskCreateDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class GetDesk(BaseModel):
    desk: Optional["GetDeskDesk"]


class GetDeskDesk(BaseModel):
    id: str
    name: str
    creation_date: Any = Field(alias="creationDate")
    modified_date: Optional[Any] = Field(alias="modifiedDate")
    owner: "GetDeskDeskOwner"
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["GetDeskDeskBureau"]
    agents: Optional[list[Optional["GetDeskDeskAgents"]]]
    agent_count: Optional[int] = Field(alias="agentCount")


class GetDeskDeskOwner(BaseModel):
    id: str


class GetDeskDeskBureau(BaseModel):
    id: str


class GetDeskDeskAgents(BaseModel):
    id: str


GetDesk.model_rebuild()
GetDeskDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class UpdateDesk(BaseModel):
    update_desk: Optional["UpdateDeskUpdateDesk"] = Field(alias="updateDesk")


class UpdateDeskUpdateDesk(BaseModel):
    id: str
    name: str
    state: EntityState
    description: Optional[str]
    objectives: Optional[str]
    instructions: Optional[str]
    bureau: Optional["UpdateDeskUpdateDeskBureau"]


class UpdateDeskUpdateDeskBureau(BaseModel):
    id: str


UpdateDesk.model_rebuild()
UpdateDeskUpdateDesk.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllBureaus(BaseModel):
    delete_all_bureaus: Optional[list[Optional["DeleteAllBureausDeleteAllBureaus"]]] = (
        Field(alias="deleteAllBureaus")
    )


class DeleteAllBureausDeleteAllBureaus(BaseModel):
    id: str
    state: EntityState


DeleteAllBureaus.model_rebuild()
